(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     50017,       1430]
NotebookOptionsPosition[     45713,       1279]
NotebookOutlinePosition[     46528,       1308]
CellTagsIndexPosition[     46397,       1302]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.450336910857295*^9, 3.450336917940371*^9}, {
  3.5689019386342635`*^9, 3.5689019483928213`*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 3.0.1 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.712160550491439*^9}],

Cell[BoxData[
 TemplateBox[{
  "ModifyBuiltIn","report",
   "\"The following built-in routines have been modified in SpinDynamica: \\!\
\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"Chop\\\", \\\",\\\", \\\"Dot\\\", \
\\\",\\\", \\\"Duration\\\", \\\",\\\", \\\"Exp\\\", \\\",\\\", \
\\\"Expand\\\", \\\",\\\", \\\"ExpandAll\\\", \\\",\\\", \\\"NumericQ\\\", \\\
\",\\\", \\\"Plus\\\", \\\",\\\", \\\"Power\\\", \\\",\\\", \\\"Simplify\\\", \
\\\",\\\", \\\"Times\\\", \\\",\\\", \\\"WignerD\\\"}], \\\"}\\\"}]\\). \
\\nEvaluate \
??\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\) to \
generate the additional definitions for \
\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\).\"",2,1,
   1,29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7121605515942216`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["opI (angular momentum operators)", "Subsubtitle",
 CellChangeTimes->{{3.456163949016762*^9, 3.4561639600646276`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "opI"}]], "Input",
 CellChangeTimes->{{3.5029428509553127`*^9, 3.502942851564311*^9}}],

Cell[BoxData[
 StyleBox["\<\"opI[spin, \[Mu]] defines an angular momentum operator for the \
indicated spin. If the symbol spin is a List, a sum over the spins in the \
list is implied, and if the symbol spin is absent, a sum over all spins in \
the current spin system is taken. The label \[Mu] may be a phase \[Phi] \
(indicating the phase angle of the spin angular momentum in the xy-plane), or \
may specify the polar angles {\[Theta],\[Phi]} (indicating spin angular \
momentum in an arbitrary direction in 3D space). The label \[Mu] may also \
take the values \\\"x\\\", \\\"y\\\", \\\"z\\\", indicating spin angular \
momentum operators along one of the Cartesian axes. Shift operators are \
indicated by using labels \\\"+\\\",\\\"-\\\", while polarization operators \
for spins-1/2 are indicated by using labels \\\"\[Alpha]\\\", \
\\\"\[Beta]\\\". If the label \[Mu] is absent, a vector of the three \
Cartesian angular momentum components is generated. Hence  opI[i].opI[j] \
defines the dot product of the angular momenta of spins i and j.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.7121605519464912`*^9},
 CellTags->"Info23712164151-6854911"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 spins-1/2", "Subsection",
 CellChangeTimes->{{3.50294288940539*^9, 3.502942891122905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.45616396286911*^9, 3.45616396576895*^9}, 
   3.456201606022471*^9, 3.456204541615698*^9, 3.456204576928049*^9, {
   3.7121605634577155`*^9, 3.712160563553652*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\"",2,3,2,29119468353368832677,"Local"},
  
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, {3.502943046043352*^9, 3.5029430543488607`*^9}, 
   3.515083856055225*^9, 3.5689019930573764`*^9, 3.7121605519789977`*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \
\\\"]\\\"}]\\).\"",2,3,3,29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, {3.502943046043352*^9, 3.5029430543488607`*^9}, 
   3.515083856055225*^9, 3.5689019930573764`*^9, 3.712160552034034*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", "\"\<x\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.456163969817183*^9, 3.456163972342784*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "x"}]],
   DisplayForm], "+", 
  TagBox[
   SubscriptBox["I", 
    RowBox[{"2", "x"}]],
   DisplayForm]}]], "Output",
 CellChangeTimes->{
  3.456163972928733*^9, {3.4561642866194344`*^9, 3.456164305639657*^9}, 
   3.456164374866177*^9, 3.456164594717111*^9, 3.456201554603448*^9, 
   3.456201608289055*^9, 3.45620218033608*^9, 3.4562024984610767`*^9, 
   3.4562028144070063`*^9, 3.456203069298373*^9, 3.456204079892432*^9, 
   3.4562041416379223`*^9, 3.456204495705676*^9, 3.4562045479051867`*^9, 
   3.4562045836977177`*^9, 3.4562048553454227`*^9, 3.4562048988566723`*^9, 
   3.461036948876019*^9, 3.461066147178043*^9, 3.50294277143346*^9, {
   3.5029430461276293`*^9, 3.5029430543842297`*^9}, 3.515083856102722*^9, 
   3.5689019958435354`*^9, 3.7121605520445414`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{"3", ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.456163979829627*^9, 3.456163982438363*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SpinSystem","invspin",
   "\"spin index \\!\\(\\*RowBox[{\\\"3\\\"}]\\) is not in current spin \
system. Use SetSpinSystem or SetBasis to set up spin system.\"",2,5,4,
   29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.45620454802361*^9, 3.4562045837324343`*^9, 3.456204855381735*^9, 
   3.456204898892465*^9, 3.461036948912499*^9, 3.461066147220221*^9, 
   3.502942771467311*^9, {3.502943046162848*^9, 3.50294305443801*^9}, 
   3.515083856161975*^9, 3.568901998073663*^9, 3.7121605520590544`*^9}],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{
  3.456163982900826*^9, {3.456164286657305*^9, 3.45616430572292*^9}, 
   3.4561643749065*^9, 3.456164594756261*^9, 3.456201554721944*^9, 
   3.4562016083257227`*^9, 3.456202180390285*^9, 3.456202498524685*^9, 
   3.456202814457005*^9, 3.45620306933387*^9, 3.4562040799247026`*^9, 
   3.456204141690165*^9, 3.456204495742557*^9, 3.45620454802697*^9, 
   3.4562045837356253`*^9, 3.456204855385301*^9, 3.45620489889548*^9, 
   3.461036948915111*^9, 3.461066147222742*^9, 3.502942771469953*^9, {
   3.502943046166103*^9, 3.5029430544408073`*^9}, 3.515083856164736*^9, 
   3.568901998078664*^9, 3.7121605520765667`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.4561642640017977`*^9, 3.456164268389361*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   SubscriptBox["I", 
    RowBox[{"1", "x"}]],
   DisplayForm], "+", 
  TagBox[
   SubscriptBox["I", 
    RowBox[{"2", "x"}]],
   DisplayForm]}]], "Output",
 CellChangeTimes->{{3.456164278954961*^9, 3.456164305755877*^9}, 
   3.4561643749501743`*^9, 3.4561645948007727`*^9, 3.456201554756299*^9, 
   3.456201608358605*^9, 3.456202180450221*^9, 3.456202498582835*^9, 
   3.456202814513796*^9, 3.4562030694149723`*^9, 3.4562040799597197`*^9, 
   3.4562041417234163`*^9, 3.4562044957886267`*^9, 3.4562045480752373`*^9, 
   3.456204583785652*^9, 3.456204855420385*^9, 3.456204898925606*^9, 
   3.461036948966371*^9, 3.461066147261222*^9, 3.502942771505698*^9, {
   3.502943046199778*^9, 3.502943054483588*^9}, 3.515083856209704*^9, 
   3.568902001381852*^9, 3.712160552089073*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", "\"\<x\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4561642640017977`*^9, 3.456164268389361*^9}, {
  3.45616431603819*^9, 3.456164316372549*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SpinSystem","invspin",
   "\"spin index \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\
\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}]\\) is not in current spin \
system. Use SetSpinSystem or SetBasis to set up spin system.\"",2,7,5,
   29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456204548136797*^9, 3.4562045838159323`*^9, 3.456204855466321*^9, 
   3.456204898963307*^9, 3.461036949017496*^9, 3.46106614729534*^9, 
   3.502942771538124*^9, {3.502943046264121*^9, 3.502943054539171*^9}, 
   3.515083856238039*^9, 3.5689020035739775`*^9, 3.7121605521025867`*^9}],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{{3.456164278954961*^9, 3.456164316828903*^9}, 
   3.456164374987397*^9, 3.456164594840184*^9, 3.456201554808868*^9, 
   3.456201608405287*^9, 3.456202180508856*^9, 3.45620249861479*^9, 
   3.456202814545471*^9, 3.456203069472464*^9, 3.456204080014398*^9, 
   3.456204141773676*^9, 3.4562044958426933`*^9, 3.4562045481391487`*^9, 
   3.4562045838191442`*^9, 3.456204855469677*^9, 3.4562048989662437`*^9, 
   3.46103694902003*^9, 3.461066147297776*^9, 3.502942771540394*^9, {
   3.502943046266816*^9, 3.502943054566655*^9}, 3.515083856269659*^9, 
   3.568902003578978*^9, 3.7121605521238017`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", "\"\<x\>\"", "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4562015593562117`*^9, 3.456201576340919*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "0"},
     {
      FractionBox["1", "2"], "0", "0", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "0", "0", 
      FractionBox["1", "2"]},
     {"0", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 2, 4, 6, 8}, {{2}, {3}, {1}, {4}, {4}, {1}, {3}, {2}}}, {
      Rational[1, 2], Rational[1, 2], Rational[1, 2], Rational[1, 2], 
       Rational[1, 2], Rational[1, 2], Rational[1, 2], Rational[
       1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.456201567520042*^9, 3.456201577175149*^9}, 
   3.45620160844302*^9, 3.456202186605445*^9, 3.456202506299741*^9, {
   3.4562028204613323`*^9, 3.456202834967774*^9}, 3.456203075180436*^9, 
   3.4562045557285833`*^9, 3.456204855816443*^9, 3.456204899077338*^9, 
   3.461036949062603*^9, 3.461066147331649*^9, 3.502942771603528*^9, {
   3.502943046300481*^9, 3.50294305463485*^9}, 3.515083856323029*^9, 
   3.568902005824106*^9, 3.7121605521431675`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", 
    RowBox[{"1", ",", "\"\<x\>\""}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4562015593562117`*^9, 3.456201583884109*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox["1", "2"]},
     {"0", "0", 
      FractionBox["1", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{2}, {1}, {4}, {3}}}, {
      Rational[1, 2], Rational[1, 2], Rational[1, 2], Rational[
       1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.456201567520042*^9, 3.4562016084770403`*^9}, 
   3.4562021892239122`*^9, 3.456204855890896*^9, 3.4562048991445427`*^9, 
   3.461036949109861*^9, 3.4610661473780127`*^9, 3.502942771634902*^9, {
   3.502943046329577*^9, 3.502943054684565*^9}, 3.515083856376707*^9, 
   3.568902008758274*^9, 3.7121605521566954`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", 
    RowBox[{"2", ",", "\"\<x\>\""}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4562015593562117`*^9, 3.456201591861993*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox["1", "2"], "0"},
     {"0", "0", "0", 
      FractionBox["1", "2"]},
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{3}, {4}, {1}, {2}}}, {
      Rational[1, 2], Rational[1, 2], Rational[1, 2], Rational[
       1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.456201567520042*^9, 3.456201608525058*^9}, 
   3.4562048559304457`*^9, 3.456204899190755*^9, 3.461036949159567*^9, 
   3.461066147425308*^9, 3.502942771684359*^9, {3.502943046380191*^9, 
   3.502943054734084*^9}, 3.515083856422086*^9, 3.5689020111054087`*^9, 
   3.712160552176177*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"opI", "[", 
      RowBox[{"1", ",", "\"\<z\>\""}], "]"}], ".", 
     RowBox[{"opI", "[", 
      RowBox[{"2", ",", "\"\<x\>\""}], "]"}]}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5029427934544983`*^9, 3.502942803254871*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox["1", "2"], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]},
     {
      FractionBox["1", "2"], "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{3}, {4}, {1}, {2}}}, {
      Rational[1, 2], Rational[-1, 2], Rational[1, 2], 
       Rational[-1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.5029427981867723`*^9, 3.502942804078628*^9}, {
   3.5029430464306917`*^9, 3.502943054785666*^9}, 3.515083856472776*^9, 
   3.568902017259761*^9, 3.712160552271744*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"2", 
    RowBox[{
     RowBox[{"opI", "[", 
      RowBox[{"1", ",", "\"\<z\>\""}], "]"}], ".", 
     RowBox[{"opI", "[", 
      RowBox[{"2", ",", "\"\<+\>\""}], "]"}]}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{3.502942813062516*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "1", "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 2, 2}, {{3}, {4}}}, {1, -1}}]]]]], "Output",
 CellChangeTimes->{
  3.5029428137550497`*^9, {3.502943046478757*^9, 3.502943054833157*^9}, 
   3.515083856522955*^9, 3.5689020195258904`*^9, 3.7121605522887573`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{
    RowBox[{"opI", "[", 
     RowBox[{"1", ",", "\"\<\[Alpha]\>\""}], "]"}], ".", 
    RowBox[{"opI", "[", 
     RowBox[{"2", ",", "\"\<\[Beta]\>\""}], "]"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{
  3.502942813062516*^9, {3.502943039870603*^9, 3.5029430511583242`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "1", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {1, {{0, 0, 0, 1, 1}, {{3}}}, {1}}]]]]], "Output",
 CellChangeTimes->{
  3.5029428137550497`*^9, {3.502943046530306*^9, 3.502943054885504*^9}, 
   3.515083856570595*^9, 3.5689020213319936`*^9, 3.7121605523027663`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{"1", ",", 
   RowBox[{"\[Pi]", "/", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502942820921385*^9, 3.502942829246269*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "x"}]],
    DisplayForm], 
   SqrtBox["2"]], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "y"}]],
    DisplayForm], 
   SqrtBox["2"]]}]], "Output",
 CellChangeTimes->{{3.5029428264944553`*^9, 3.502942829626066*^9}, {
   3.502943046581544*^9, 3.502943054936495*^9}, 3.515083856623725*^9, 
   3.5689020232471027`*^9, 3.7121605523177767`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Pi]", "/", "3"}], ",", 
     RowBox[{"\[Pi]", "/", "4"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502942834701989*^9, 3.502942839572648*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox["3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "x"}]],
       DisplayForm], 
      SqrtBox["2"]], "+", 
     FractionBox[
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "y"}]],
       DisplayForm], 
      SqrtBox["2"]]}], ")"}]}], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm], "2"]}]], "Output",
 CellChangeTimes->{
  3.5029428401914253`*^9, {3.502943046632201*^9, 3.502943054985626*^9}, 
   3.515083856674358*^9, 3.5689020249151983`*^9, 3.7121605523327875`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Pi]", "/", "3"}], ",", 
    RowBox[{"\[Pi]", "/", "4"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.502942845013709*^9, 3.502942845196547*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox["3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "x"}]],
       DisplayForm], 
      SqrtBox["2"]], "+", 
     FractionBox[
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "y"}]],
       DisplayForm], 
      SqrtBox["2"]]}], ")"}]}], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm], "2"], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox["3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      TagBox[
       SubscriptBox["I", 
        RowBox[{"2", "x"}]],
       DisplayForm], 
      SqrtBox["2"]], "+", 
     FractionBox[
      TagBox[
       SubscriptBox["I", 
        RowBox[{"2", "y"}]],
       DisplayForm], 
      SqrtBox["2"]]}], ")"}]}], "+", 
  FractionBox[
   TagBox[
    SubscriptBox["I", 
     RowBox[{"2", "z"}]],
    DisplayForm], "2"]}]], "Output",
 CellChangeTimes->{
  3.502942845682477*^9, {3.502943046682481*^9, 3.502943055036656*^9}, 
   3.515083856726762*^9, 3.5689020277693615`*^9, 3.71216055235282*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"opI", "[", "1", "]"}], ".", 
  RowBox[{"opI", "[", "2", "]"}]}]], "Input",
 CellChangeTimes->{{3.502942859643547*^9, 3.502942862644006*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "x"}]],
     DisplayForm], 
    AdjustmentBox["\[Bullet]",
     BoxMargins->{{-0.3, 0}, {0, 0}}], 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"2", "x"}]],
     DisplayForm]}],
   DisplayForm], "+", 
  TagBox[
   RowBox[{
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "y"}]],
     DisplayForm], 
    AdjustmentBox["\[Bullet]",
     BoxMargins->{{-0.3, 0}, {0, 0}}], 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"2", "y"}]],
     DisplayForm]}],
   DisplayForm], "+", 
  TagBox[
   RowBox[{
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "z"}]],
     DisplayForm], 
    AdjustmentBox["\[Bullet]",
     BoxMargins->{{-0.3, 0}, {0, 0}}], 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"2", "z"}]],
     DisplayForm]}],
   DisplayForm]}]], "Output",
 CellChangeTimes->{
  3.502942863177659*^9, {3.502943046748776*^9, 3.502943055101482*^9}, 
   3.5150838568418427`*^9, 3.56890203001449*^9, 3.7121605523733196`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"opI", "[", "1", "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5029428654708557`*^9, 3.502942869348213*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "x"}]],
    DisplayForm]}], "+", 
  RowBox[{"b", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "y"}]],
    DisplayForm]}], "+", 
  RowBox[{"c", " ", 
   TagBox[
    SubscriptBox["I", 
     RowBox[{"1", "z"}]],
    DisplayForm]}]}]], "Output",
 CellChangeTimes->{
  3.5029428699404163`*^9, {3.502943046798703*^9, 3.5029430551682653`*^9}, 
   3.5150838568898287`*^9, 3.5689020318905973`*^9, 3.712160552389319*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
spin \"I\" (quantum number 1) and spin \"S\" (quantum number 3/2)\
\>", "Subsection",
 CellChangeTimes->{{3.50294288940539*^9, 3.5029429237226667`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<I\>\"", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<S\>\"", ",", 
      RowBox[{"3", "/", "2"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.45616396286911*^9, 3.45616396576895*^9}, 
   3.456201606022471*^9, 3.456204541615698*^9, 3.456204576928049*^9, {
   3.502942926908246*^9, 3.50294293666857*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"\\\\\\\"I\\\\\\\"\\\", \\\",\\\", \
\\\"1\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"\\\\\\\"S\
\\\\\\\"\\\", \\\",\\\", FractionBox[\\\"3\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"",2,19,6,29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, 3.5029429372930517`*^9, 3.502943055237032*^9, 
   3.5150838569566803`*^9, 3.5689020361428404`*^9, 3.7121605524098315`*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"\
\\\\\\\"I\\\\\\\"\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"\\\\\\\"S\\\\\\\"\\\", \\\",\\\", FractionBox[\
\\\"3\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \
\\\"]\\\"}]\\).\"",2,19,7,29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.456163966369556*^9, {3.456164286553218*^9, 3.45616430554272*^9}, 
   3.456164374062786*^9, 3.456164593915292*^9, 3.4562015544899282`*^9, 
   3.456201608205554*^9, 3.4562021802379427`*^9, 3.456202498330545*^9, 
   3.4562028142931004`*^9, 3.456203069214973*^9, 3.456204078992474*^9, 
   3.456204140752467*^9, 3.456204494804265*^9, 3.4562045420959673`*^9, {
   3.456204577367599*^9, 3.456204583615263*^9}, 3.456204854481304*^9, 
   3.45620489799152*^9, 3.461036948022011*^9, 3.461066145853022*^9, 
   3.502942771367139*^9, 3.5029429372930517`*^9, 3.502943055237032*^9, 
   3.5150838569566803`*^9, 3.5689020361428404`*^9, 3.7121605524303455`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", "\"\<x\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.456163969817183*^9, 3.456163972342784*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   SubscriptBox["I", "x"],
   DisplayForm], "+", 
  TagBox[
   SubscriptBox["S", "x"],
   DisplayForm]}]], "Output",
 CellChangeTimes->{
  3.456163972928733*^9, {3.4561642866194344`*^9, 3.456164305639657*^9}, 
   3.456164374866177*^9, 3.456164594717111*^9, 3.456201554603448*^9, 
   3.456201608289055*^9, 3.45620218033608*^9, 3.4562024984610767`*^9, 
   3.4562028144070063`*^9, 3.456203069298373*^9, 3.456204079892432*^9, 
   3.4562041416379223`*^9, 3.456204495705676*^9, 3.4562045479051867`*^9, 
   3.4562045836977177`*^9, 3.4562048553454227`*^9, 3.4562048988566723`*^9, 
   3.461036948876019*^9, 3.461066147178043*^9, 3.50294277143346*^9, 
   3.502942940775837*^9, 3.5029430553390837`*^9, 3.5150838570567913`*^9, 
   3.568902038294964*^9, 3.712160552460867*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", "\"\<x\>\"", "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.502942944959155*^9, 3.502942954188238*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "0", "0"},
     {"0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "0"},
     {
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "1", "0", "0", "0", "0", "0"},
     {"0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "1", "0", "0", "0", "0"},
     {"0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "1", "0", "0", "0"},
     {"0", "0", "0", "1", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0"},
     {"0", "0", "0", "0", "1", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0"},
     {"0", "0", "0", "0", "0", "1", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"]},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]]},
     {"0", "0", "0", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {12, 12}, 0, {
     1, {{0, 2, 5, 7, 10, 14, 17, 20, 24, 27, 29, 32, 34}, {{4}, {2}, {5}, {
       1}, {3}, {6}, {2}, {1}, {7}, {5}, {2}, {8}, {4}, {6}, {3}, {9}, {5}, {
       4}, {10}, {8}, {5}, {11}, {7}, {9}, {6}, {12}, {8}, {7}, {11}, {8}, {
       10}, {12}, {9}, {11}}}, {
      Rational[1, 2] 3^Rational[1, 2], 2^Rational[-1, 2], Rational[1, 2] 
       3^Rational[1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], Rational[1, 2] 
       3^Rational[1, 2], 2^Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 
       1, 2^Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 1, 2^
       Rational[-1, 2], 2^Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 1,
        2^Rational[-1, 2], 1, Rational[1, 2] 3^Rational[1, 2], 2^
       Rational[-1, 2], 1, Rational[1, 2] 3^Rational[1, 2], 2^Rational[-1, 2],
        2^Rational[-1, 2], 1, Rational[1, 2] 3^Rational[1, 2], 2^
       Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 2^Rational[-1, 2], 
       Rational[1, 2] 3^Rational[1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], 
       Rational[1, 2] 3^Rational[1, 2], 2^Rational[-1, 2]}}]]]]], "Output",
 CellChangeTimes->{3.502942954756135*^9, 3.502943055485649*^9, 
  3.515083857124948*^9, 3.568902045541378*^9, 3.71216055247888*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opI", "[", 
  RowBox[{"1", ",", "\"\<x\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.456163979829627*^9, 3.456163982438363*^9}, {
  3.5029429600775957`*^9, 3.5029429603400593`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SpinSystem","invspin",
   "\"spin index \\!\\(\\*RowBox[{\\\"1\\\"}]\\) is not in current spin \
system. Use SetSpinSystem or SetBasis to set up spin system.\"",2,22,8,
   29119468353368832677,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.45620454802361*^9, 3.4562045837324343`*^9, 
  3.456204855381735*^9, 3.456204898892465*^9, 3.461036948912499*^9, 
  3.461066147220221*^9, 3.502942771467311*^9, 3.5029429607311897`*^9, 
  3.5029430555556307`*^9, 3.515083857205694*^9, 3.5689020518627396`*^9, 
  3.7121605525094166`*^9}],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{
  3.456163982900826*^9, {3.456164286657305*^9, 3.45616430572292*^9}, 
   3.4561643749065*^9, 3.456164594756261*^9, 3.456201554721944*^9, 
   3.4562016083257227`*^9, 3.456202180390285*^9, 3.456202498524685*^9, 
   3.456202814457005*^9, 3.45620306933387*^9, 3.4562040799247026`*^9, 
   3.456204141690165*^9, 3.456204495742557*^9, 3.45620454802697*^9, 
   3.4562045837356253`*^9, 3.456204855385301*^9, 3.45620489889548*^9, 
   3.461036948915111*^9, 3.461066147222742*^9, 3.502942771469953*^9, 
   3.50294296073402*^9, 3.502943055587941*^9, 3.5150838572396193`*^9, 
   3.568902051920743*^9, 3.7121605525264263`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", 
    RowBox[{"\"\<I\>\"", ",", "\"\<x\>\""}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4562015593562117`*^9, 3.456201583884109*^9}, {
  3.502942978430256*^9, 3.502942979228273*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0", 
      FractionBox["1", 
       SqrtBox["2"]]},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      FractionBox["1", 
       SqrtBox["2"]], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {12, 12}, 0, {
     1, {{0, 1, 3, 4, 5, 7, 8, 9, 11, 12, 13, 15, 16}, {{2}, {1}, {3}, {2}, {
       5}, {4}, {6}, {5}, {8}, {7}, {9}, {8}, {11}, {10}, {12}, {11}}}, {
      2^Rational[-1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], 2^
       Rational[-1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], 2^
       Rational[-1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], 2^
       Rational[-1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], 2^
       Rational[-1, 2], 2^Rational[-1, 2], 2^Rational[-1, 2], 2^
       Rational[-1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.456201567520042*^9, 3.4562016084770403`*^9}, 
   3.4562021892239122`*^9, 3.456204855890896*^9, 3.4562048991445427`*^9, 
   3.461036949109861*^9, 3.4610661473780127`*^9, 3.502942771634902*^9, {
   3.502942975465193*^9, 3.502942980116284*^9}, 3.5029430556767387`*^9, 
   3.5150838573107862`*^9, 3.568902054700902*^9, 3.712160552541957*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", 
    RowBox[{"\"\<S\>\"", ",", "\"\<x\>\""}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4562015593562117`*^9, 3.456201591861993*^9}, {
  3.502942985309757*^9, 3.502942985756459*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "0"},
     {
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", 
      "0"},
     {"0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "1", "0", "0", "0", "0"},
     {"0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0", "1", "0", "0", "0"},
     {"0", "0", "0", "1", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0"},
     {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0"},
     {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"]},
     {"0", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", 
      FractionBox[
       SqrtBox["3"], "2"], "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {12, 12}, 0, {
     1, {{0, 1, 2, 3, 5, 7, 9, 11, 13, 15, 16, 17, 18}, {{4}, {5}, {6}, {1}, {
       7}, {2}, {8}, {3}, {9}, {4}, {10}, {5}, {11}, {6}, {12}, {7}, {8}, {
       9}}}, {Rational[1, 2] 3^Rational[1, 2], Rational[1, 2] 
       3^Rational[1, 2], Rational[1, 2] 3^Rational[1, 2], Rational[1, 2] 
       3^Rational[1, 2], 1, Rational[1, 2] 3^Rational[1, 2], 1, 
       Rational[1, 2] 3^Rational[1, 2], 1, 1, Rational[1, 2] 3^Rational[1, 2],
        1, Rational[1, 2] 3^Rational[1, 2], 1, Rational[1, 2] 
       3^Rational[1, 2], Rational[1, 2] 3^Rational[1, 2], Rational[1, 2] 
       3^Rational[1, 2], Rational[1, 2] 3^Rational[1, 2]}}]]]]], "Output",
 CellChangeTimes->{{3.456201567520042*^9, 3.456201608525058*^9}, 
   3.4562048559304457`*^9, 3.456204899190755*^9, 3.461036949159567*^9, 
   3.461066147425308*^9, 3.502942771684359*^9, 3.5029429863301277`*^9, 
   3.502943055764407*^9, 3.515083857360323*^9, 3.5689020615782957`*^9, 
   3.7121605525699577`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{
    RowBox[{"opI", "[", 
     RowBox[{"\"\<I\>\"", ",", "\"\<z\>\""}], "]"}], "^", "2"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5029427934544983`*^9, 3.502942803254871*^9}, {
  3.5029429939182987`*^9, 3.502943001052041*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {12, 12}, 0, {
     1, {{0, 1, 1, 2, 3, 3, 4, 5, 5, 6, 7, 7, 8}, {{1}, {3}, {4}, {6}, {7}, {
       9}, {10}, {12}}}, {1, 1, 1, 1, 1, 1, 1, 1}}]]]]], "Output",
 CellChangeTimes->{{3.5029427981867723`*^9, 3.502942804078628*^9}, 
   3.5029430017468443`*^9, 3.502943055807129*^9, 3.515083857411353*^9, 
   3.568902066662586*^9, 3.7121605525964785`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AngularMomentumOperator"}]], "Input",
 CellChangeTimes->{{3.5029430941437063`*^9, 3.502943102283341*^9}}],

Cell[BoxData[
 StyleBox["\<\"AngularMomentumOperator is a synonym for opI\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.7121605527861123`*^9},
 CellTags->"Info263712164152-6854911"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{
    RowBox[{"AngularMomentumOperator", "[", 
     RowBox[{"\"\<I\>\"", ",", "\"\<z\>\""}], "]"}], "^", "2"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{3.502943118621866*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {12, 12}, 0, {
     1, {{0, 1, 1, 2, 3, 3, 4, 5, 5, 6, 7, 7, 8}, {{1}, {3}, {4}, {6}, {7}, {
       9}, {10}, {12}}}, {1, 1, 1, 1, 1, 1, 1, 1}}]]]]], "Output",
 CellChangeTimes->{3.502943119440399*^9, 3.515083857744585*^9, 
  3.568902079024293*^9, 3.71216055290972*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1093, 746},
WindowMargins->{{6, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info23712164151-6854911"->{
  Cell[2057, 62, 1174, 17, 113, "Print",
   CellTags->"Info23712164151-6854911"]},
 "Info263712164152-6854911"->{
  Cell[43536, 1223, 197, 4, 40, "Print",
   CellTags->"Info263712164152-6854911"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info23712164151-6854911", 46176, 1293},
 {"Info263712164152-6854911", 46290, 1296}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 197, 3, 30, "Input"],
Cell[767, 27, 147, 4, 36, "Print"],
Cell[917, 33, 838, 15, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1792, 53, 123, 1, 28, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1940, 58, 114, 2, 30, "Input"],
Cell[2057, 62, 1174, 17, 113, "Print",
 CellTags->"Info23712164151-6854911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3268, 84, 98, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[3391, 89, 252, 4, 30, "Input"],
Cell[3646, 95, 1112, 19, 47, "Message"],
Cell[4761, 116, 1248, 20, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6046, 141, 130, 2, 30, "Input"],
Cell[6179, 145, 843, 19, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7059, 169, 153, 3, 30, "Input"],
Cell[7215, 174, 577, 11, 21, "Message"],
Cell[7795, 187, 669, 10, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8501, 202, 204, 5, 30, "Input"],
Cell[8708, 209, 810, 18, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9555, 232, 265, 7, 30, "Input"],
Cell[9823, 241, 658, 12, 23, "Message"],
Cell[10484, 255, 648, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11169, 269, 216, 5, 30, "Input"],
Cell[11388, 276, 1588, 40, 142, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13013, 321, 241, 6, 30, "Input"],
Cell[13257, 329, 1260, 33, 142, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14554, 367, 241, 6, 30, "Input"],
Cell[14798, 375, 1232, 33, 142, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16067, 413, 357, 10, 30, "Input"],
Cell[16427, 425, 1162, 33, 142, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17626, 463, 331, 10, 30, "Input"],
Cell[17960, 475, 931, 26, 94, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18928, 506, 371, 10, 30, "Input"],
Cell[19302, 518, 894, 24, 94, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20233, 547, 173, 4, 30, "Input"],
Cell[20409, 553, 458, 16, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20904, 574, 254, 7, 30, "Input"],
Cell[21161, 583, 681, 26, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21879, 614, 227, 6, 30, "Input"],
Cell[22109, 622, 1160, 48, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23306, 675, 175, 4, 30, "Input"],
Cell[23484, 681, 1043, 43, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24564, 729, 204, 5, 30, "Input"],
Cell[24771, 736, 520, 19, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25340, 761, 162, 3, 43, "Subsection"],
Cell[CellGroupData[{
Cell[25527, 768, 441, 11, 30, "Input"],
Cell[25971, 781, 1118, 18, 47, "Message"],
Cell[27092, 801, 1259, 20, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28388, 826, 130, 2, 30, "Input"],
Cell[28521, 830, 797, 17, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29355, 852, 214, 5, 30, "Input"],
Cell[29572, 859, 3770, 102, 482, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33379, 966, 206, 4, 30, "Input"],
Cell[33588, 972, 580, 11, 21, "Message"],
Cell[34171, 985, 666, 10, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34874, 1000, 298, 7, 30, "Input"],
Cell[35175, 1009, 2927, 74, 410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38139, 1088, 298, 7, 30, "Input"],
Cell[38440, 1097, 2845, 68, 446, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41322, 1170, 326, 8, 30, "Input"],
Cell[41651, 1180, 1711, 34, 230, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43399, 1219, 134, 2, 30, "Input"],
Cell[43536, 1223, 197, 4, 40, "Print",
 CellTags->"Info263712164152-6854911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43770, 1232, 269, 7, 30, "Input"],
Cell[44042, 1241, 1631, 33, 230, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

